from airflow.operators.python import PythonOperator

from .utility import fail, pass_, skip

__all__ = (
    "SkipTask",
    "FailTask",
    "PassTask",
)


def SkipTask(task_id: str, **kwargs) -> PythonOperator:
    return PythonOperator(task_id=task_id, python_callable=skip, **kwargs)


def FailTask(task_id: str, **kwargs) -> PythonOperator:
    return PythonOperator(task_id=task_id, python_callable=fail, **kwargs)


def PassTask(task_id: str, **kwargs) -> PythonOperator:
    return PythonOperator(task_id=task_id, python_callable=pass_, **kwargs)



from unittest.mock import MagicMock

from airflow_common_operators.models import BashCommands, DagCleanup


class TestModels:
    def test_bash(self):
        cmds = BashCommands(
            commands=[
                "echo 'hello world'",
                "echo 'goodbye world'",
            ]
        )
        assert cmds.model_dump() == "bash -lc 'set -ex\necho 'hello world'\necho 'goodbye world''"

    def test_dag_cleanup(self):
        d = DagCleanup()
        d.cleanup_dag_runs(session=MagicMock(), params={})



from typing import List

from pydantic import BaseModel, model_serializer

__all__ = ("BashCommands",)


class BashCommands(BaseModel):
    commands: List[str]
    quote: str = "'"
    escape: bool = False
    login: bool = True

    @model_serializer()
    def _serialize(self) -> str:
        from airflow_common_operators import in_bash

        return in_bash("\n".join(["set -ex"] + self.commands), quote=self.quote, escape=self.escape, login=self.login)



__all__ = ("link",)


def link(source, target, unlink: bool = True):
    """Link a file or directory to another location.

    Args:
        source (str): Source file or directory.
        target (str): Target file or directory.
        unlink (bool, optional): Unlink the target if it exists. Defaults to True.

    Returns:
        str: Command to run.
    """
    if unlink:
        return f"ln -sfn {source} {target}"
    else:
        return f"ln -s {source} {target}"
